@@ -14,7 +14,6 @@ import argparse
 import os
 
 from debtcollector import removals
-from positional import positional
 
 from keystoneclient.auth import base
 
@@ -24,7 +23,6 @@ from keystoneclient.auth import base
     version='2.1.0',
     removal_version='3.0.0'
 )
-@positional()
 def register_argparse_arguments(parser, argv, default=None):
     """Register CLI options needed to create a plugin.
 
@@ -32,7 +30,7 @@ def register_argparse_arguments(parser, argv, default=None):
     the options required for that specific plugin if available.
 
     :param argparse.ArgumentParser: the parser to attach argparse options to.
-    :param list argv: the arguments provided to the appliation.
+    :param List argv: the arguments provided to the application.
     :param str/class default: a default plugin name or a plugin object to use
                               if one isn't specified by the CLI. default: None.
 
